%Description: Generates pitch and yaw time-series data for a
% constant-density spiral scan.
%Author: Liquid Instruments

clc
clear
close all

%% Configurable paramaters
amplitudeScaling = 0.75; %User defined scaling factor for amplitude (0 to 1)
numPoints = 500; %How many points in the scan?
numRings = 5; %How many rings in the spiral?

%% Constants
amplitudeFull = 1;

%% Maths
finalAmplitude = amplitudeScaling*amplitudeFull;
initialAmplitude = 0;
lengthOfArc = numRings*pi*(finalAmplitude-initialAmplitude);
deltaArc = lengthOfArc/numPoints;

ringSpacing = finalAmplitude/numRings;

phase = [];
phase(1) = 0;

for i = 2:1:numPoints %Recursive function to find even spaced points
    phase(i) = sqrt(((deltaArc*4*pi)/ringSpacing)+phase(i-1)^2);
end

amplitude = ringSpacing.*phase/(2*pi);

pitchData = amplitude.*cos(phase); %Stich phase and amplitude data together to generate pitch and yaw
yawData = amplitude.*sin(phase);

%% Plot
figure
plot(yawData,pitchData,'.');
xlim([-1 1]);
ylim([-1 1]);
xlabel('Yaw [Volts]');
ylabel('Pitch [Volts]');

%% Write to CSV
yawData = transpose(yawData);
pitchData = transpose(pitchData);
dataCombined = [yawData,pitchData];
csvwrite('timeSeriesWaveform.csv',dataCombined,0,0);


